.slider.svelte-1iz48mk{-webkit-appearance:none;width:100%;height:5px;border-radius:5px;background:#d3d3d3;outline:none;opacity:0.7;-webkit-transition:.2s;transition:opacity .2s}.slider.svelte-1iz48mk::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;width:25px;height:25px;border-radius:10%;background:#DA9C20;cursor:pointer}.slider.svelte-1iz48mk::-moz-range-thumb{width:25px;height:25px;border-radius:50%;background:#DA9C20;cursor:pointer}