import{i as t}from"./client.8ef88fa2.js";function n(t){var n=t-1;return n*n*n+1}function o(o,r,e){var a=getComputedStyle(o),i="none"===a.transform?"":a.transform,f=r.from.width/o.clientWidth,c=r.from.height/o.clientHeight,s=(r.from.left-r.to.left)/f,u=(r.from.top-r.to.top)/c,d=Math.sqrt(s*s+u*u),m=e.delay,l=void 0===m?0:m,h=e.duration,p=void 0===h?function(t){return 120*Math.sqrt(t)}:h,g=e.easing,v=void 0===g?n:g;return{delay:l,duration:t(p)?p(d):p,easing:v,css:function(t,n){return"transform: ".concat(i," translate(").concat(n*s,"px, ").concat(n*u,"px);")}}}export{o as f};
