nav.svelte-jhgkr8{border-bottom:1px solid rgba(255,62,0,0.1);font-weight:300;padding:0 1em}ul.svelte-jhgkr8{margin:0;padding:0}ul.svelte-jhgkr8::after{content:'';display:block;clear:both}li.svelte-jhgkr8{display:block;float:left}[aria-current].svelte-jhgkr8{position:relative;display:inline-block}[aria-current].svelte-jhgkr8::after{position:absolute;content:'';width:calc(100% - 1em);height:2px;background-color:rgb(255,62,0);display:block;bottom:-1px}a.svelte-jhgkr8{text-decoration:none;padding:1em 0.5em;display:block}
.fa.svelte-88c8nf{align-items:center;display:inline-flex;justify-content:center;height:1.25rem;width:1.25rem}.is-low.svelte-88c8nf{margin-bottom:-0.25rem}.is-lower.svelte-88c8nf{margin-bottom:-0.35rem}.is-48.svelte-88c8nf{margin-top:8px;width:48px;height:48px}.is-36.svelte-88c8nf{margin-top:4px!important;width:36px;height:36px}.is-24.svelte-88c8nf{vertical-align:-0.35em;width:24px;height:24px}.is-info.svelte-88c8nf{color:#209cee}.is-small.svelte-88c8nf{height:.75rem !important;width:.75rem !important}.is-small.is-low.svelte-88c8nf{margin-bottom:-0.15rem!important}@-webkit-keyframes svelte-88c8nf-spinner-spin{from{transform:rotate(0deg)}to{transform:rotate(360deg)}}@-moz-keyframes svelte-88c8nf-spinner-spin{from{transform:rotate(0deg)}to{transform:rotate(360deg)}}@-o-keyframes svelte-88c8nf-spinner-spin{from{transform:rotate(0deg)}to{transform:rotate(360deg)}}@-ms-keyframes svelte-88c8nf-spinner-spin{from{transform:rotate(0deg)}to{transform:rotate(360deg)}}@keyframes svelte-88c8nf-spinner-spin{from{transform:rotate(0deg)}to{transform:rotate(360deg)}}.spin.svelte-88c8nf{-webkit-animation:svelte-88c8nf-spinner-spin  1s steps(8) infinite;-moz-animation:svelte-88c8nf-spinner-spin  1s steps(8) infinite;-o-animation:svelte-88c8nf-spinner-spin  1s steps(8) infinite;animation:svelte-88c8nf-spinner-spin  1s steps(8) infinite}
.slider.svelte-1iz48mk{-webkit-appearance:none;width:100%;height:5px;border-radius:5px;background:#d3d3d3;outline:none;opacity:0.7;-webkit-transition:.2s;transition:opacity .2s}.slider.svelte-1iz48mk::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;width:25px;height:25px;border-radius:10%;background:#DA9C20;cursor:pointer}.slider.svelte-1iz48mk::-moz-range-thumb{width:25px;height:25px;border-radius:50%;background:#DA9C20;cursor:pointer}
.notification.svelte-63zoqh{bottom:5rem;right:1rem;position:fixed;width:300px;background:#EFF0EB;padding:1rem}.slider.svelte-63zoqh{-webkit-appearance:none;width:100%;height:5px;border-radius:5px;background:#d3d3d3;outline:none;opacity:0.7;-webkit-transition:.2s;transition:opacity .2s}.slider.svelte-63zoqh::-webkit-slider-thumb{-webkit-appearance:none;appearance:none;width:25px;height:25px;border-radius:10%;background:#DA9C20;cursor:pointer}.slider.svelte-63zoqh::-moz-range-thumb{width:25px;height:25px;border-radius:50%;background:#DA9C20;cursor:pointer}
main.svelte-1kb58f{position:relative;max-width:56em;background-color:white;padding:2em;padding-bottom:100px;margin:0 auto;box-sizing:border-box}
h1.svelte-hc3g3x,p.svelte-hc3g3x{margin:0 auto}h1.svelte-hc3g3x{font-size:2.8em;font-weight:700;margin:0 0 0.5em 0}p.svelte-hc3g3x{margin:1em auto}@media(min-width: 480px){h1.svelte-hc3g3x{font-size:4em}}